function WC_daily_pcolor( inDir , outDir , WC_nums , avg_pd_min , flag_v2_std_or_mc , month_num , flag_I_Data_Avail_make_plot , flag_WS_WDir_make_plot , flag_I_Data_Avail_6_Panel_make_plot , flag_WS_WDir_6_Panel_make_plot , flag_6_Panel_single_cbars )

% Author: Paul T. Quelet
% 
% Last Update Noted: 14 April 2015
% 
% Made with Matlab 2014b
% IMPORTANT NOTE: GRAPHICS WILL NOT WORK WITH EARLIER VERSIONS OF CODE
% 
% Example function call:
% WC_daily_pcolor( 'E:\XPIA_Research\XPIA_Dataviewer_Matlab_Plot_Codes\WLS7' , 'E:\XPIA_Research\XPIA_Dataviewer_Matlab_Plot_Codes\WLS7' , 2 : 3 , 2 , 3 : 3, 13 )
% 
% =========================================================================
% INPUT      DESCRIPTION                            TYPE        UNITS
% -------------------------------------------------------------------------

% inDir      Input directory                        string      (none)
% outDir     Output directory                       string      (none)
% WC_nums    Wind Cube Numbers                      double      (none)
% avg_pd_min averaging period                       double      [minutes]
% flag_v2_std_or_mc 'std' for standard files        string
%                   'mc'  for motion compensated files (normal)
% month_num  month number(e.g. Mar = 3)             double      (none)
% fontsize   size of font for plots                 double      (none)
% =========================================================================

%% I. Set WindCube Parameters

fss                                 = 'FontSize';

fontsize                            = 13 ;

time_threshold                      = .0001 ; % Fraction of a day of accuracy for datenumber test

one_day_advance                     = 1.0000001 ;

FULL_CIRC_DEG                       = 360.0 ;

curr_exper_abbr                     = 'XPIA' ;

% Other experiments string abbreviations include the following:
% 'BLADE' , 'NWTC' , 'CWEX11' , 'TWICS' , 'TODS' , 'CWEX13' , 'LUMEX'

% Set starting and ending days:
% **Note: The month gets used with these days if the user selects that month:

Feb_day_start_num                   = 09 ; % February start day to run this code for
Feb_day_start_str                   = num2str( Feb_day_start_num ) ;
Feb_day_end_num                     = eomday( 2015 , 2 ) ; % February end day to run this code for, end of month day function

Mar_day_start_num                   = 01 ; % March start day to run this code for
Mar_day_end_num                     = eomday( 2015 , 3 ) ; % March end day to run this code for, end of month day function
Mar_day_end_str                     = num2str( Mar_day_end_num ) ;

Apr_day_start_num                   = 01 ; % April start day to run this code for
Apr_day_end_num                     = eomday( 2015 , 4 ) ; % April end day to run this code for, end of month day function
Apr_day_end_str                     = num2str( Apr_day_end_num ) ;

May_day_start_num                   = 24 ; % May start day to run this code for
May_day_end_num                     = 28 ; % May end day to run this code for
May_day_end_str                     = num2str( May_day_end_num ) ;

Jun_day_start_num                   = 01 ; % May start day to run this code for
Jun_day_end_num                     = 09 ; % May end day to run this code for
Jun_day_end_str                     = num2str( Jun_day_end_num ) ;

%% II. Set constants

NUM_MIN_HOUR                        = 60.0 ;
NUM_HOUR_DAY                        = 24.0 ;

%% III. Setup the Master Time Axis:

% Set the believed starting and ending times using datenum() to convert the date strings

time_start_str                      = strcat(  Feb_day_start_str , '/02/2015 00:00:00'   ) ;
master_time_start                   = datenum( time_start_str    , 'dd/mm/yyyy HH:MM:SS' ) ;

time_end_str                        = strcat(  Jun_day_end_str   , '/06/2015 00:00:00'   ) ;
master_time_end                     = datenum( time_end_str      , 'dd/mm/yyyy HH:MM:SS' ) ;

% Setup a master time axis with equal avg_pd_min strides from the beginning to end date times:
masterTime                          = ( master_time_start : avg_pd_min / ( NUM_MIN_HOUR * NUM_HOUR_DAY ) : master_time_end )' ;

% Construct two more columns of the same length as the regular time axis, and start filled with NaN:
cols_choices                        = 2 : 2 + length( WC_nums ) - 1 ;
masterTime( : , cols_choices  )     = NaN( length( masterTime ) , length( WC_nums ) ) ;

%% IV. Load data to plot

for j_wc = WC_nums
    
    % Assign information base upon Wind Cube Number:
    
    switch j_wc
        case 1
            WCnum                   = 49 ;
            WCnum_str               = num2str( WCnum ) ;
        case 2
            WCnum                   = 61 ;
            WCnum_str               = num2str( WCnum ) ;
        case 3
            WCnum                   = 68 ;
            WCnum_str               = num2str( WCnum ) ;
        case 4
            WCnum                   = 16 ;
            WCnum_str               = num2str( WCnum ) ;
    end
    
    load( strcat( inDir , curr_exper_abbr , '_' , WCnum_str, '_' , num2str( avg_pd_min ) , 'min_avg_' , flag_v2_std_or_mc , '.mat' ) )
    
    % Set the current instrument to be the datenumber that will go into the calculation
    
    dn = datenum( double( WC_datevec ) ) ;
    
    %% V. Set the parmeters now that values have come in
    
    switch j_wc
        case 1
            num_heights_49          = 10 ;
            alt49                   = alt ; 
        case 2
            num_heights_61          = 10 ;
            alt61                   = alt ; 
        case 3
            num_heights_68          = 10 ;
            alt68                   = alt ; 
        case 4
            num_heights_16          = 11 ;
            alt16                   = alt ; 
    end
    
    
    %% VI. Perform QA/QC on alpha
    
    alpha( alpha == Inf | alpha == -Inf ) = NaN ;
    
    %% VII. Set time period of WC operation to find out when the are operational
    
    for i_time = 1 : length( masterTime )
        
        diff_inds = find( abs( masterTime( i_time, 1 ) - dn ) < time_threshold ) ; % Test if this is nonzero with find()
        
        if diff_inds >= 1
            masterTime( i_time , j_wc ) = 1 ; % Note the time in the WC time row as a one (for "good")
        end
        
    end % End test for loop over length of time
    
    % Assign information base upon Wind Cube Number:
    
    switch j_wc
        case 1
            disp( 'Not able to transfer data right now...' ) ;
        case 2
            %% VIII. Create full length variables for WC61
            
            % Create the sizes of the matrices (total master times x number of measurement heights):
            
            masterVh61      = NaN( length( masterTime ) , num_heights_61 + 1 ) ;
            masterAzim61    = NaN( length( masterTime ) , num_heights_61 + 1 ) ;
            masterAlpha61   = NaN( length( masterTime ) , num_heights_61     ) ;
            masterTKE61     = NaN( length( masterTime ) , num_heights_61 + 1 ) ;
            masterI61       = NaN( length( masterTime ) , num_heights_61 + 1 ) ;
            masterAvail61   = NaN( length( masterTime ) , num_heights_61 + 1 ) ;
            
            % Initialize the data time to zero:
            
            c_data_time = 0 ;
            
            % Loop through al the master times of the axis:
            
            for i_time = 1 : length( masterTime )
                
                % Check if it is a "good" time for the column of this WindCube:
                
                if masterTime( i_time , 2 ) == 1 % Column 2 is the appropriate column for these times
                    
                    % If a good time, advance the time counter of the data:
                    
                    c_data_time = c_data_time + 1 ;
                    
                    % Set the data values matrix to the appropriate slot of the master time:
                    
                    masterVh61(    i_time , 1 : num_heights_61     ) = Vh(    c_data_time , : ) ;
                    masterAzim61(  i_time , 1 : num_heights_61     ) = Azim(  c_data_time , : ) ;
                    masterAlpha61( i_time , 1 : num_heights_61 - 1 ) = alpha( c_data_time , : ) ;
                    masterTKE61(   i_time , 1 : num_heights_61     ) = TKE2(  c_data_time , : ) ; % Notice use of TKE2 definition
                    masterI61(     i_time , 1 : num_heights_61     ) = I2(    c_data_time , : ) ; % Notice use of I2 definition
                    masterAvail61( i_time , 1 : num_heights_61     ) = Avail( c_data_time , : ) ;
                    
                end % End check if good master time
                
            end % End loop over all the master times
            
        case 3
            
            %%  IX. Create full length variables for WC68
            
            masterVh68      = NaN( length( masterTime ) , num_heights_68 + 1 ) ;
            masterAzim68    = NaN( length( masterTime ) , num_heights_68 + 1 ) ;
            masterAlpha68   = NaN( length( masterTime ) , num_heights_68     ) ;
            masterTKE68     = NaN( length( masterTime ) , num_heights_68 + 1 ) ;
            masterI68       = NaN( length( masterTime ) , num_heights_68 + 1 ) ;
            masterAvail68   = NaN( length( masterTime ) , num_heights_68 + 1 ) ;
            
            % Initialize the data time to zero:
            
            c_data_time = 0 ;
            
            % Loop through al the master times of the axis:
            
            for i_time = 1 : length( masterTime )
                
                % Check if it is a "good" time for the column of this WindCube:
                
                if masterTime( i_time , 3 ) == 1 % Column 3 is the appropriate column for these times
                    
                    % If a good time, advance the time counter of the data:
                    
                    c_data_time = c_data_time + 1 ;
                    
                    % Set the data values matrix to the appropriate slot of the master time:
                    
                    masterVh68(    i_time , 1 : num_heights_68     ) = Vh(    c_data_time , : ) ;
                    masterAzim68(  i_time , 1 : num_heights_68     ) = Azim(  c_data_time , : ) ;
                    masterAlpha68( i_time , 1 : num_heights_68 - 1 ) = alpha( c_data_time , : ) ;
                    masterTKE68(   i_time , 1 : num_heights_68     ) = TKE2(  c_data_time , : ) ; % Notice use of TKE2 definition
                    masterI68(     i_time , 1 : num_heights_68     ) = I2(    c_data_time , : ) ; % Notice use of I2 definition
                    masterAvail68( i_time , 1 : num_heights_68     ) = Avail( c_data_time , : ) ;
                    
                end % End check if good master time
                
            end % End loop over all the master times
            
            
        case 4
            
            %%  X. Create full length variables for WC16
            
            masterVh16      = NaN( length( masterTime ) , num_heights_16 + 1 ) ;
            masterAzim16    = NaN( length( masterTime ) , num_heights_16 + 1 ) ;
            masterAlpha16   = NaN( length( masterTime ) , num_heights_16     ) ;
            masterTKE16     = NaN( length( masterTime ) , num_heights_16 + 1 ) ;
            masterI16       = NaN( length( masterTime ) , num_heights_16 + 1 ) ;
            masterAvail16   = NaN( length( masterTime ) , num_heights_16 + 1 ) ;
            
            % Initialize the data time to zero:
            
            c_data_time = 0 ;
            
            % Loop through al the master times of the axis:
            
            for i_time = 1 : length( masterTime )
                
                % Check if it is a "good" time for the column of this WindCube:
                
                if masterTime( i_time , 4 ) == 1 % Column 4 is the appropriate column for these times
                    
                    % If a good time, advance the time counter of the data:
                    
                    c_data_time = c_data_time + 1 ;
                    
                    % Set the data values matrix to the appropriate slot of the master time:
                    
                    masterVh16(    i_time , 1 : num_heights_16     ) = Vh(    c_data_time , : ) ;
                    masterAzim16(  i_time , 1 : num_heights_16     ) = Azim(  c_data_time , : ) ;
                    masterAlpha16( i_time , 1 : num_heights_16 - 1 ) = alpha( c_data_time , : ) ;
                    masterTKE16(   i_time , 1 : num_heights_16     ) = TKE2(  c_data_time , : ) ; % Notice use of TKE2 definition
                    masterI16(     i_time , 1 : num_heights_16     ) = I2(    c_data_time , : ) ; % Notice use of I2 definition
                    masterAvail16( i_time , 1 : num_heights_16     ) = Avail( c_data_time , : ) ;
                    
                end % End check if good master time
                
            end % End loop over all the master times
            
    end % End switch statement choice of WC numbers
    
end % End loop over the Wind Cube Numbers

%% XI. Create Time and Height Matricies

% Time, Horizontal Axis

x               = ( 0 : avg_pd_min / NUM_MIN_HOUR : NUM_HOUR_DAY )' ;

% Vertical Axis

y               = alt61 - 10 ; % Subtract 10m to setup the vertical axis
y(11)           = 230; % Set the largest value of the vertical axis to be 230m

if exist( 'alt16' , 'var' )
    y16         = 0.5 * (alt16(1:end-1) + alt16(2:end)) ; % Take mean in between consecutive values
    y16         = [ 30 ; y16 ; 210 ] ; % Attach appropriate height values on the beginning and end
end

% try
%     y16         = alt16 - 10 ; % Subtract 10m to setup the vertical axis
%     y16(12)     = 210; % Set the largest value of the vertical axis to be 210m
% catch
%     warning( 'No WC16 data found. Continuing...' ) ;
% end




% avg_y61         = ( avg_alt61 - 10 )' ;
% avg_y61( 10 )   = 220 ; % Highest height 220 m
% 
% avg_y68         = ( avg_alt - 10 )' ;
% avg_y68( 10 )   = 220 ; % Highest height 220 m
% 
% avg_y16         = ( avg_alt - 10 )' ;
% avg_y16( 10 )   = 200 ; % Highest height 200 m

%% XII. Loop over the months:

for k_month = month_num
    switch k_month
        case 2
            day_start_num           = Feb_day_start_num ; % Start day set by the user
            day_end_num             = Feb_day_end_num   ; % End   day set by the user
        case 3
            day_start_num           = Mar_day_start_num ; % Start day set by the user
            day_end_num             = Mar_day_end_num   ; % End   day set by the user
        case 4
            day_start_num           = Apr_day_start_num ; % Start day set by the user
            day_end_num             = Apr_day_end_num   ; % End   day set by the user  
        case 5
            day_start_num           = May_day_start_num ; % Start day set by the user
            day_end_num             = May_day_end_num   ; % End   day set by the user
        case 6
            day_start_num           = Jun_day_start_num ; % Start day set by the user
            day_end_num             = Jun_day_end_num   ; % End   day set by the user
    end
    
    % Set the number string format to prepend a leading zero to the digits if it is less than 10
    
    month_str                       = sprintf( '%02d' , k_month ) ;
    
    % Loop through all the days specified from above selected by the user:
    
    for l_day = day_start_num : day_end_num
        
        % Set the number string format to prepend a leading zero to the digits if it is less than 10
        
        day_str                     = sprintf( '%02d' , l_day ) ;
        
        sing_day_date_str_start     = strcat('2015/' , month_str , '/' , day_str , ' 00:00' ) ; % Start time of case study
        % sing_day_date_str_start     = strcat('2015/' , month_str , '/' , day_str , ' 12:00' ) ; % Start time of case study
        
        horiz_data_label_str        = sing_day_date_str_start ;
        
        file_label_str              = strcat( sing_day_date_str_start( 1 : 4 ) , '_' , month_str, '_' , day_str ) ;
        
        datenum_start               = datenum( sing_day_date_str_start ) ;
        one_day_advanced_criteria   = datenum_start + one_day_advance ;
        
        % Label for location
        % (Make sure same number of columns with decimal places for vertical concatenation:)
        
        WC61_lat_lon_str            = [' 40.004881N' ; '105.0039  W' ; ' 1582 m MSL' ; ] ; % S guy wires of BAO Tower
        WC68_lat_lon_str            = [' 40.004881N' ; '105.0039  W' ; ' 1582 m MSL' ; ] ; % S guy wires of BAO Tower
        WC16_lat_lon_str            = [' 40.004881N' ; '105.0039  W' ; ' 1582 m MSL' ; ] ; % S guy wires of BAO Tower
        
        % Index the windcube datasets based on the time period of interest:
        good_time_indices = find( masterTime( : , 1 ) >= datenum_start & masterTime( : , 1 ) <= one_day_advanced_criteria ) ;
        
        if nansum( masterTime( good_time_indices , 2 ) ) > 1 || nansum( masterTime( good_time_indices , 3 ) ) > 1 % If either time axis exists, then plot
            %% XIII. I & Data avail. 4 panel plot for Data Viewer
            
            if flag_I_Data_Avail_make_plot == 1
                
                % Initialize a new figure maximized:
                
                figure('units','normalized','outerposition', [ 0 0 1 1 ] )
                
                % -------------------
                
                subplot( 2 , 2 , 1 ) ; % WC68 I (Upper left)
                
                
                % Make the plot, then store the properties:
                
                [p1]                            = pcolor( x , y , masterI68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p1 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                h1                              = colorbar( 'location' , 'eastoutside' ) ;
                set( h1 , fss , fontsize ) ;
                color_num_min                   = 0.0 ;
                color_num_max                   = 0.6 ;
                caxis([color_num_min color_num_max]) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                cbfreeze( h1 ) ; % Freeze the colorbar colors
                freezeColors ;  % Freeze the colors
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize   )
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = 'WC68 Turbulence Intensity' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC68_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % -------------------
                
                subplot( 2 , 2 , 2 ) ; % WC61 I (Upper right)
                
                % Make the plot, then store the properties:
                
                [p2]                            = pcolor( x , y , masterI61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p2 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                h2                              = colorbar( 'location' , 'eastoutside' ) ;
                set( h2 , fss , fontsize ) ;
                color_num_min                   =  0.0 ;
                color_num_max                   =  0.6 ;
                caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                cbfreeze( h2 ) ; % Freeze the colorbar colors
                freezeColors ;  % Freeze the colors
                
                % Set the x (horizontal) axis parameters:
                x_min                           =  0.0 ;
                x_stride                        =  4.0 ;
                x_max                           = 24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize   )
                
                % Set the y (vertical) axis parameters:
                y_min                           = 40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = 'WC61 Turbulence Intensity' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC61_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % -------------------
                
                subplot( 2 , 2 , 3 ) ; % WC68 Data availability (Lower left)
                
                % Make the plot, then store the properties:
                
                [p3]                            = pcolor( x , y , masterAvail68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p3 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                h3                              = colorbar( 'location' , 'eastoutside' ) ;
                set( h3 , fss , fontsize ) ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 100.0 ;
                caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( jet( 10 ) )
                cbfreeze( h3 ) ; % Freeze the colorbar colors
                freezeColors ;  % Freeze the colors
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize   )
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       = y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = strcat( {'WC68 '} , num2str(avg_pd_min) , '-min. Data Availability (%)' ) ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC68_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % -------------------
                
                
                subplot( 2 , 2 , 4 ) ; % WC61 Data availability (Lower right)
                
                % Make the plot, then store the properties:
                
                [p4]                            = pcolor( x , y , masterAvail61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p4 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                h4                              = colorbar( 'location' , 'eastoutside' ) ;
                set( h4 , fss , fontsize ) ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 100.0 ;
                caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( jet( 10 ) )
                cbfreeze( h4 ) ; % Freeze the colorbar colors
                freezeColors ;  % Freeze the colors
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize   )
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = strcat( {'WC61 '} , num2str(avg_pd_min) , '-min. Data Availability (%)' ) ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC61_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % Save the plot created:
                
                saveas( gcf , strcat( outDir , file_label_str , '_I-Avail' ) , 'png' ) ;
                
            end % End if statement flag for flag_I_Data_Avail_make_plot
            
            
            %% XIV. WS & WD 4 panel plot for Data Viewer
            
            if flag_WS_WDir_make_plot == 1
                
                % Initialize a new figure maximized:
                
                figure('units','normalized','outerposition', [ 0 0 1 1 ] )
                
                % -------------------
                
                subplot( 2 , 2 , 1 ) ; % WC68 WS (Upper left)
                
                % Make the plot, then store the properties:
                
                [p1]                            = pcolor( x , y , masterVh68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p1 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax1                             = gca ;
                color_num_min                   =  0.0 ;
                color_num_max                   = 15.0 ;
                caxis( ax1 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax1 , jet( 15 ) ) ; % Set the color map
                % freezeColors ;  % Freeze the colors
                
                % Create a colorbar and then set its properties:
                h1                              = colorbar( ax1, 'location' , 'eastoutside' ) ;
                set( h1 , fss , fontsize ) ;
                h1.Limits                       = [ color_num_min color_num_max ] ;
                
                % cbfreeze( h1 ) ; % cbfreeze() does not work Matlab 2014b and onward...
                % http://www.mathworks.com/matlabcentral/answers/163213-making-two-different-color-maps-in-2014b
                % http://www.mathworks.com/matlabcentral/newsreader/view_thread/338192
                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                
                % Title parameters:
                title_str                       = 'WC68 Wind Speed (m s^{-1})' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC68_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % -------------------
                
                subplot( 2 , 2 , 2 ) ; % WC61 WS (Upper right)
                
                % Make the plot, then store the properties:
                
                [p2]                            = pcolor( x , y , masterVh61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p2 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax2                             = gca ;
                color_num_min                   =  0.0 ;
                color_num_max                   = 15.0 ;
                caxis( ax2 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax2 , jet( 15 ) ) ; % Set the color map
                
                % Create a colorbar and then set its properties
                
                h2                              = colorbar( ax2 , 'location' , 'eastoutside' ) ;
                set( h2 , fss , fontsize ) ;
                h2.Limits                       = [ color_num_min color_num_max ] ;
                                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                
                % Title parameters:
                title_str                       = 'WC61 Wind Speed (m s^{-1})' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize = 10.0 ;
                text(  0.5 , 200 , WC61_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % -------------------
                
                subplot( 2 , 2 , 3 ) ; % WC68 WDir (Lower left)
                
                % Make the plot, then store the properties:
                
                [p3]                            = pcolor( x , y , masterAzim68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p3 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax3                             = gca ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 360.0 ; % Hope to make this 360.0 with WDcolorbar
                caxis( ax3 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax3 , hsv ) ; % Set the colormap, hope to be WDcolorbar soon
                
                % Create a colorbar and then set its properties
                h3                              = colorbar( ax3 , 'location' , 'eastoutside' ) ;
                set( h3 , fss , fontsize ) ;
                WDir_deg_stride                 = 45.0 ;
                set( h3 , 'YTick', 0 : WDir_deg_stride : FULL_CIRC_DEG )
                h3.Limits                       = [ color_num_min color_num_max ] ;
                                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Label the horizontal axis with a date:
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs(y_lab_inds)         =  y_lab_strs(y_lab_inds) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = 'WC68 Wind Direction ({\circ})' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC68_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % -------------------
                
                subplot( 2 , 2 , 4 ) ; % WC61 WDir (Lower right)
                
                % Make the plot, then store the properties:
                
                [p4]                            = pcolor( x , y , masterAzim61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p4 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax4                             = gca ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 360.0 ;
                caxis( ax4 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax4 , hsv ) ; % Set the colormap, hope to be WDcolorbar soon
                
                % Create a colorbar and then set its properties
                h4                              = colorbar( ax4 , 'location' , 'eastoutside' ) ;
                set( h4 , fss , fontsize ) ;
                WDir_deg_stride                 = 45.0 ;
                set( h4 , 'YTick', 0 : WDir_deg_stride : FULL_CIRC_DEG )
                h4.Limits                       = [color_num_min color_num_max] ;
                                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [x_min x_max] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Label the horizontal axis with a date:
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Height AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str = 'WC61 Wind Direction ({\circ})' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text(  0.5 , 200 , WC61_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                
                % Save the plot created:
                
                saveas( gcf , strcat( outDir , file_label_str , '_WS_WDir' ) , 'png' ) ;
                
            end % End if statement flag for flag_I_Data_Avail_make_plot
            
            %% XV. I & Data avail. 6 panel plot for Data Viewer
            
            if flag_I_Data_Avail_6_Panel_make_plot == 1
                
                % Initialize a new figure maximized:
                
                figure('units','normalized','outerposition', [ 0 0 1 1 ] )
                
                % -------------------
                
                subplot( 3 , 2 , 1 ) ; % WC68 I (Upper left)
                
                
                % Make the plot, then store the properties:
                
                [p1]                            = pcolor( x , y , masterI68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p1 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                if flag_6_Panel_single_cbars == 0
                    
                    h1                          = colorbar( 'location' , 'eastoutside' ) ;
                    set( h1 , fss , fontsize ) ;
                    color_num_min               = 0.0 ;
                    color_num_max               = 0.6 ;
                    caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                    colormap( jet( 10 ) )
                    
                end

                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize )
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs(y_lab_inds)         =  y_lab_strs(y_lab_inds) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = 'Turbulence Intensity' ;
                title( title_str , fss , fontsize  )
                
                % -------------------
                
                subplot( 3 , 2 , 2 ) ; % WC68 Data availability (Upper right)
                
                % Make the plot, then store the properties:
                
                [p2]                            = pcolor( x , y , masterAvail68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p2 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                if flag_6_Panel_single_cbars == 0
                    
                    h2 = colorbar( 'location' , 'eastoutside' ) ;
                    set( h2 , fss , fontsize ) ;
                    color_num_min               =   0.0 ;
                    color_num_max               = 100.0 ;
                    caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                    colormap( jet( 10 ) )
                    
                end

                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize )
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                
                if     flag_6_Panel_single_cbars == 0 % If NOT a single color bar, do the normal thing
                    ylabel( vert_label_str )
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                elseif flag_6_Panel_single_cbars == 1 % If a single color bar, Do not put the axis label or numerical labels on.
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' , 'YTickLabel' , '' ) ;
                end
                
                % Title parameters:
                title_str                       = strcat( num2str(avg_pd_min) , '-min. Data Availability (%)' ) ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text( 0.5 , 80 , WC68_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                text( 16  , 80 , 'WC68' , fss , text_box_fontsize ) 
                
                % -------------------
                
                subplot( 3 , 2 , 3 ) ; % WC61 I (Middle left)
                
                % Make the plot, then store the properties:
                
                [p3]                            = pcolor( x , y , masterI61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p3 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                if flag_6_Panel_single_cbars == 0
                    
                    h3                          = colorbar( 'location' , 'eastoutside' ) ;
                    set( h3 , fss , fontsize ) ;
                    color_num_min               = 0.0 ;
                    color_num_max               = 0.6 ;
                    caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                    
                end

                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize )
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs(y_lab_inds)         =  y_lab_strs(y_lab_inds) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % -------------------
                
                subplot( 3 , 2 , 4 ) ; % WC61 Data availability (Middle right)
                
                % Make the plot, then store the properties:
                
                [p4]                            = pcolor( x , y , masterAvail61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p4 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                if flag_6_Panel_single_cbars == 0
                    
                    h4                          = colorbar( 'location' , 'eastoutside' ) ;
                    set( h4 , fss , fontsize ) ;
                    color_num_min               =   0.0 ;
                    color_num_max               = 100.0 ;
                    caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                    colormap( jet( 10 ) )
                    
                end

                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize )
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                
                if     flag_6_Panel_single_cbars == 0 % If NOT a single color bar, do the normal thing
                    ylabel( vert_label_str )
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                elseif flag_6_Panel_single_cbars == 1 % If a single color bar, Do not put the axis label or numerical labels on.
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' , 'YTickLabel' , '' ) ;
                end
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text( 0.5 , 80 , WC61_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                text( 16  , 80 , 'WC61' , fss , text_box_fontsize ) 
                
                % -------------------
               
                subplot( 3 , 2 , 5 ) ; % WC16 I (Lower left)
                
                % Make the plot, then store the properties:
                
                [p5]                            = pcolor( x , y16 , masterI16( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p5 , 'EdgeColor' ,  'none' )
                
                % Create a colorbar and then set its properties
                
                if flag_6_Panel_single_cbars == 1
                    
                    h_plot_5                    = get( subplot (3 , 2 , 5 ) , 'Position' ) ;
                    cbar_left_offset            = 0.015 ;
                    cbar_horiz_width            = 0.020 ;
                    h5                          = colorbar( 'Position', [ h_plot_5(1) + h_plot_5(3) + cbar_left_offset  h_plot_5(2)   cbar_horiz_width  h_plot_5(2) + h_plot_5(3) * 2.1] ) ;
                    
                else
                    
                    h5                          = colorbar( 'location' , 'eastoutside' ) ;
                    
                end

                set( h5 , fss , fontsize ) ;
                color_num_min                   = 0.0 ;
                color_num_max                   = 0.6 ;
                caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( jet( 10 ) )
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize   )
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;

                % Set the y (vertical) axis parameters:
                
                y_axis_nums                     = alt16 ; % The height values are not equally spaced
                y_lab_strs                      = num2cell( alt16 ) ;
                y_lab_inds                      = [ 1 4 6 9 11 ] ; % Chosen very exactly for WC16
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       = y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                                
                % -------------------
                
                subplot( 3 , 2 , 6 ) ; % WC16 Data availability (Lower right)
                
                % Make the plot, then store the properties:
                
                [p6]                            = pcolor( x , y16 , masterAvail16( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p6 , 'EdgeColor' ,  'none')
                
                % Create a colorbar and then set its properties
                
                if flag_6_Panel_single_cbars == 1
                    
                    h_plot_6                    = get( subplot (3 , 2 , 6 ) , 'Position' ) ;
                    cbar_left_offset            = 0.015 ;
                    cbar_horiz_width            = 0.020 ;
                    h6                          = colorbar( 'Position', [ h_plot_6(1) + h_plot_6(3) + cbar_left_offset  h_plot_6(2)   cbar_horiz_width  h_plot_6(2) + h_plot_6(3) * 2.1] ) ;
                    
                else
                    
                    h6                          = colorbar( 'location' , 'eastoutside' ) ;
                    
                end

                set( h6 , fss , fontsize ) ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 100.0 ;
                caxis( [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( jet( 10 ) )
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize   )
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;
                
                % Set the y (vertical) axis parameters:
                
                y_axis_nums                     = alt16 ; % The height values are not equally spaced
                y_lab_strs                      = num2cell( alt16 ) ;
                y_lab_inds                      = [ 1 4 6 9 11 ] ; % Chosen very exactly for WC16
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       = y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                
                if     flag_6_Panel_single_cbars == 0 % If NOT a single color bar, do the normal thing
                    ylabel( vert_label_str )
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                elseif flag_6_Panel_single_cbars == 1 % If a single color bar, Do not put the axis label or numerical labels on.
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' , 'YTickLabel' , '' ) ;
                end
                                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text( 0.5 , 80 , WC16_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                text( 16  , 80 , 'WC16 v2' , fss , text_box_fontsize ) 

                % -------------------
                
                % Save the plot created:
                
                saveas( gcf , strcat( outDir , file_label_str , '_I-Avail_6_Panel' ) , 'png' ) ;
                
            end % End if statement flag for flag_I_Data_Avail_make_plot
            
            %% XVI. WS & WD 6 panel plot for Data Viewer
            
            if flag_WS_WDir_6_Panel_make_plot == 1
                
                % Initialize a new figure maximized:
                
                figure('units','normalized','outerposition', [ 0 0 1 1 ] )
                
                % -------------------
                
                subplot( 3 , 2 , 1 ) ; % WC68 WS (Upper left)
                
                % Make the plot, then store the properties:
                
                [p1]                            = pcolor( x , y , masterVh68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p1 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax1                             = gca ;
                color_num_min                   =  0.0 ;
                color_num_max                   = 15.0 ;
                caxis( ax1 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax1 , jet( 15 ) ) ; % Set the color map
                
                % Create a colorbar and then set its properties (if not making a single colorbar for the figure):
                
                if flag_6_Panel_single_cbars == 0
                    
                    h1                          = colorbar( ax1, 'location' , 'eastoutside' ) ;
                    set( h1 , fss , fontsize ) ;
                    h1.Limits                   = [color_num_min color_num_max] ;
                    
                end
                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the x ticks very carefully
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % Title parameters:
                title_str                       = 'Wind Speed (m s^{-1})' ;
                title( title_str , fss , fontsize  )
                                
                % -------------------
                
                subplot( 3 , 2 , 2 ) ; % WC68 WDir (Upper right)
                
                % Make the plot, then store the properties:
                
                [p2]                            = pcolor( x , y , masterAzim68( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p2 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax2                             = gca ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 360.0 ; % Hope to make this 360.0 with WDcolorbar
                caxis( ax2 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax2 , hsv ) ; % Set the colormap, hope to be WDcolorbar soon
                
                % Create a colorbar and then set its properties, if not a single colorbar for the whole plot:
                
                if flag_6_Panel_single_cbars == 0
                    
                    h2                          = colorbar( ax2 , 'location' , 'eastoutside' ) ;
                    set( h2 , fss , fontsize ) ;
                    WDir_deg_stride             = 45.0 ;
                    set( h2 , 'YTick', 0 : WDir_deg_stride : FULL_CIRC_DEG )
                    h2.Limits                   = [color_num_min color_num_max] ;
                    
                end
                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_68 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_68  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                
                if     flag_6_Panel_single_cbars == 0 % If NOT a single color bar, do the normal thing
                    ylabel( vert_label_str )
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                elseif flag_6_Panel_single_cbars == 1 % If a single color bar, Do not put the axis label or numerical labels on.
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' , 'YTickLabel' , '' ) ;
                end
                
                % Title parameters:
                title_str                       = 'Wind Direction ({\circ})' ;
                title( title_str , fss , fontsize  )
                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text( 0.5 , 80 , WC68_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                text( 16  , 80 , 'WC68' , fss , text_box_fontsize )            
                
                % -------------------
                                
                subplot( 3 , 2 , 3 ) ; % WC61 WS (Middle Left)
                
                % Make the plot, then store the properties:
                
                [p3]                            = pcolor( x , y , masterVh61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p3 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax3                             = gca ;
                color_num_min                   =  0.0 ;
                color_num_max                   = 15.0 ;
                caxis( ax3 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax3 , jet( 15 ) ) ; % Set the color map
                
                % Create a colorbar and then set its properties if there is not a single color bar for the whole figure:
                
                if flag_6_Panel_single_cbars == 0
                    
                    h3                          = colorbar( ax3 , 'location' , 'eastoutside' ) ;
                    set( h3 , fss , fontsize ) ;
                    h3.Limits                   = [color_num_min color_num_max] ;
                    
                end
                                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;
                
                % -------------------
                
                subplot( 3 , 2 , 4 ) ; % WC61 WDir (Middle right)
                
                % Make the plot, then store the properties:
                
                [p4]                            = pcolor( x , y , masterAzim61( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p4 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax4                             = gca ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 360.0 ;
                caxis( ax4 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax4 , hsv ) ; % Set the colormap, hope to be WDcolorbar soon
                
                % Create a colorbar and then set its properties, as long as there is no single colorbar for entire figure:

                if flag_6_Panel_single_cbars == 0
                    
                    h4                          = colorbar( ax4 , 'location' , 'eastoutside' ) ;
                    set( h4 , fss , fontsize ) ;
                    WDir_deg_stride             = 45.0 ;
                    set( h4 , 'YTick', 0 : WDir_deg_stride : FULL_CIRC_DEG )
                    h4.Limits                   = [ color_num_min color_num_max ] ;
                    
                end
                
                % Set the x (horizontal) axis parameters:
                hand_x_axis                     =   gca ;
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                % set( hand_x_axis , 'XTick' ,  x_min : x_stride : x_max , 'XTickLabel' ,  { '12' , '16' , '20' , '0' , '4' , '8' , '12'}  , 'XMinorTick' , 'on' , 'TickDir' , 'Out' , fss , fontsize )
                hand_x_axis.YRuler.MinorTick    = 0 : 1 : 24 ; % Set the spacing of the y ticks very carefully
                
                % Set the y (vertical) axis parameters:
                y_min                           =  40.0 ;
                y_max                           = 220.0 ;
                y_axis_nums                     = linspace( y_min, y_max , num_heights_61 ) ; % The y_stride is every 20.0 m
                y_lab_strs                      = num2cell( linspace( y_min , y_axis_nums( end ) , num_heights_61  ) ) ;
                y_lab_EveryThisMany             = 2 ;
                y_lab_inds                      = 1 : y_lab_EveryThisMany : length(y_lab_strs) ;
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       =  y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs ,'YMinorTick','off') ;

                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text( 0.5 , 80 , WC61_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                text( 16  , 80 , 'WC61' , fss , text_box_fontsize ) 
                
                % -------------------
                
                subplot( 3 , 2 , 5 ) ; % WC16 WS (Lower left)
                
                % Make the plot, then store the properties:
                
                [p5]                            = pcolor( x , y16 , masterVh16( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p5 , 'EdgeColor' ,  'none' )
                
                % Set the colormap and its properties:
                ax5                             = gca ;
                color_num_min                   =  0.0 ;
                color_num_max                   = 15.0 ;
                caxis( ax5 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax5 , jet( 15 ) ) ; % Set the color map
                                
                % Create a colorbar depending upon if single or entire figure:
                
                if     flag_6_Panel_single_cbars == 1
                    
                    h_plot_5                    = get( subplot (3 , 2 , 5 ) , 'Position' ) ;
                    cbar_left_offset            = 0.015 ;
                    cbar_horiz_width            = 0.020 ;
                    h5                          = colorbar( 'Position', [ h_plot_5(1) + h_plot_5(3) + cbar_left_offset  h_plot_5(2)   cbar_horiz_width  h_plot_5(2) + h_plot_5(3) * 2.1] ) ;
                    
                elseif flag_6_Panel_single_cbars == 0
                    
                    h5                          = colorbar( ax5 , 'location' , 'eastoutside' ) ;
                    set( h5 , fss , fontsize ) ;
                    h5.Limits                   = [ color_num_min color_num_max ] ;
                    
                end
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize   )
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;

                % Set the y (vertical) axis parameters:
                
                y_axis_nums                     = alt16 ; % The height values are not equally spaced
                y_lab_strs                      = num2cell( alt16 ) ;
                y_lab_inds                      = [ 1 4 6 9 11 ] ; % Chosen very exactly for WC16
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       = y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                ylabel( vert_label_str )
                set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                                
                % -------------------
                
                subplot( 3 , 2 , 6 ) ; % WC16 Data availability (Lower right)
                
                % Make the plot, then store the properties:
                
                [p6]                            = pcolor( x , y16 , masterAzim16( good_time_indices , : )' ) ;
                set( gca , fss , fontsize )
                set( p6 , 'EdgeColor' ,  'none')
                
                % Set the colormap and its properties:
                ax6                             = gca ;
                color_num_min                   =   0.0 ;
                color_num_max                   = 360.0 ;
                caxis( ax6 , [ color_num_min color_num_max ] ) ;  % sets color limits to min max values. Values between cmin and cmax linearly map to the current colormap.
                colormap( ax6 , hsv ) ; % Set the colormap, hope to be WDcolorbar soon

                % Create a colorbar and then set its properties depending upon if it is for the full figure or not:
                
                if     flag_6_Panel_single_cbars == 1
                    
                    h_plot_6 = get( subplot ( 3 , 2 , 6 ) , 'Position' ) ;
                    cbar_left_offset            = 0.015 ;
                    cbar_horiz_width            = 0.020 ;
                    h6                          = colorbar( 'Position', [ h_plot_6(1) + h_plot_6(3) + cbar_left_offset  h_plot_6(2)   cbar_horiz_width  h_plot_6(2) + h_plot_6(3) * 2.1] ) ;
                    
                elseif flag_6_Panel_single_cbars == 0
                              
                    h6                          = colorbar( ax6 , 'location' , 'eastoutside' ) ;
                    set( h6 , fss , fontsize ) ;
                    WDir_deg_stride             = 45.0 ;
                    set( h6 , 'YTick', 0 : WDir_deg_stride : FULL_CIRC_DEG )
                    h6.Limits                   = [color_num_min color_num_max] ;
                    
                end
                
                % Set the x (horizontal) axis parameters:
                x_min                           =   0.0 ;
                x_stride                        =   4.0 ;
                x_max                           =  24.0 ;
                xlim( [ x_min x_max ] ) % 24 hours
                set( gca , 'XTick' ,  x_min : x_stride : x_max  , 'XMinorTick' , 'off' , 'TickDir' , 'Out' , fss , fontsize   )
                xlabel( strcat( { 'UTC from ' } , horiz_data_label_str ) ) ;
                
                % Set the y (vertical) axis parameters:
                
                y_axis_nums                     = alt16 ; % The height values are not equally spaced
                y_lab_strs                      = num2cell( alt16 ) ;
                y_lab_inds                      = [ 1 4 6 9 11 ] ; % Chosen very exactly for WC16
                y_plot_strs                     = cell( length( y_lab_strs ) , 1 ) ;
                y_plot_strs( y_lab_inds )       = y_lab_strs( y_lab_inds ) ;
                vert_label_str                  = 'Hgt. AGL (m)' ;
                
                if     flag_6_Panel_single_cbars == 0 % If NOT a single color bar, do the normal thing
                    ylabel( vert_label_str )
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' ) ;
                elseif flag_6_Panel_single_cbars == 1 % If a single color bar, Do not put the axis label or numerical labels on.
                    set( gca , 'YTick' , y_axis_nums , 'YTickLabel' , y_plot_strs , 'YMinorTick' , 'off' , 'YTickLabel' , '' ) ;
                end
                                
                % Text box parameters:
                text_box_fontsize               = 10.0 ;
                text( 0.5 , 80 , WC16_lat_lon_str( 1 : 3 , : ) , fss , text_box_fontsize )
                text( 16  , 80 , 'WC16 v2' , fss , text_box_fontsize ) 
                
                % ----------------------
                
                % Save the plot created:
                
                saveas( gcf , strcat( outDir , file_label_str , '_WS_WDir_6_Panel' ) , 'png' ) ;
                
            end % End if statement flag for flag_I_Data_Avail_make_plot
            
        end % End if statement of single day range
        
        close all % Close all the figures
        
    end % End loop over all days (l_days) in the current month needing to make plots for
    
end % End the loop over the months (k_month)

end % End of the WC_daily_pcolor() function
